import type { GraphqlUI } from '@teambit/graphql';
import { SlotRegistry } from '@teambit/harmony';
import type { ReactRouterUI } from '@teambit/react-router';
import React, { ReactNode } from 'react';
import { UIRootFactory } from './ui-root.ui';
declare type HudSlot = SlotRegistry<ReactNode>;
declare type ContextSlot = SlotRegistry<ContextType>;
export declare type UIRootRegistry = SlotRegistry<UIRootFactory>;
declare type ContextType = React.JSXElementConstructor<React.PropsWithChildren<any>>;
/**
 * extension
 */
export declare class UiUI {
    /**
     * GraphQL extension.
     */
    private graphql;
    /**
     * react-router extension.
     */
    private router;
    /**
     * ui root registry.
     */
    private uiRootSlot;
    /** slot for overlay ui elements */
    private hudSlot;
    /** slot for context provider elements */
    private contextSlot;
    constructor(
    /**
     * GraphQL extension.
     */
    graphql: GraphqlUI, 
    /**
     * react-router extension.
     */
    router: ReactRouterUI, 
    /**
     * ui root registry.
     */
    uiRootSlot: UIRootRegistry, 
    /** slot for overlay ui elements */
    hudSlot: HudSlot, 
    /** slot for context provider elements */
    contextSlot: ContextSlot);
    render(rootExtension: string): Promise<void>;
    /** adds elements to the Heads Up Display */
    registerHudItem: (element: React.ReactNode) => void;
    registerContext(context: ContextType): void;
    registerRoot(uiRoot: UIRootFactory): void;
    private getRoot;
    static slots: ((registerFn: () => string) => SlotRegistry<React.ReactNode>)[];
    static dependencies: import("@teambit/harmony").Aspect[];
    static runtime: import("@teambit/harmony").RuntimeDefinition;
    static provider([graphql, router]: [GraphqlUI, ReactRouterUI], config: any, [uiRootSlot, hudSlot, contextSlot]: [UIRootRegistry, HudSlot, ContextSlot]): Promise<UiUI>;
}
export {};
